import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  timeParse,
  timeFormat
} from 'd3';
import { dropdownMenu } from './dropdownMenu';
import { scatterPlot } from './scatterPlot';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');
const parseDate = timeParse("%d/%m/%Y");
const formatDate = timeFormat("%b %d");

let data;
let xColumn;
let yColumn;

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  select('#x-menu')
    .call(dropdownMenu, {
      options: data.columns,
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });
  
  select('#y-menu')
    .call(dropdownMenu, {
      options: ['Depth', 'Temp'],
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });
  
  svg.call(scatterPlot, {
    xValue: d => d.Date,
    xAxisLabel: '',
    yValue: d => d[yColumn],
    circleRadius: 10,
    yAxisLabel: yColumn,
    margin: { top: 10, right: 40, bottom: 140, left: 150 },
    width,
    height,
    data
  });
};

csv('https://vizhub.com/careyshan/datasets/borehole_dummydatadt.csv')
  .then(loadeddata => {
    data = loadeddata;
    data.forEach(d => {
      d.Depth = +d.Depth;
      d.Date = parseDate(d.Date);
      d.Temp = +d.Temp;
  });
  xColumn = data.columns[0];
  yColumn = data.columns[1];
  render();
});